@@ -2,6 +2,65 @@
 import argparse
 from pathlib import Path
 
+class Args(object):
+    def __init__(self, initial_data):
+        # Input/Output/Temp
+        self.input = None
+        self.temp = None
+        self.output_file = None
+
+        # Splitting
+        self.scenes = None
+        self.split_method = None
+        self.extra_split = None
+        self.min_scene_len = None
+
+        # PySceneDetect split
+        self.threshold = None
+
+        # AOM Keyframe split
+        self.reuse_first_pass = None
+
+        # Encoding
+        self.passes = None
+        self.video_params = None
+        self.encoder = None
+        self.workers = None
+        self.config = None
+
+        self.video_params = None
+
+        # FFmpeg params
+        self.ffmpeg_pipe = None
+        self.ffmpeg = None
+        self.audio_params = None
+        self.pix_format = None
+
+        # Misc
+        self.logging = None
+        self.resume = None
+        self.no_check = None
+        self.keep = None
+
+        # Boost
+        self.boost = None
+        self.boost_range = None
+        self.boost_limit = None
+
+        # Vmaf
+        self.vmaf = None
+        self.vmaf_path = None
+
+        # Target Vmaf
+        self.vmaf_target = None
+        self.vmaf_steps = None
+        self.min_cq = None
+        self.max_cq = None
+        self.vmaf_plots = None
+        self.n_threads = None
+
+        for key in initial_data:
+            setattr(self, key, initial_data[key])
 
 def arg_parsing():
     """Command line parsing"""
@@ -29,7 +88,7 @@ def arg_parsing():
     parser.add_argument('--passes', '-p', type=int, default=2, help='Specify encoding passes', choices=[1, 2])
     parser.add_argument('--video_params', '-v', type=str, default=None, help='encoding settings')
     parser.add_argument('--encoder', '-enc', type=str, default='aom', help='Choosing encoder',
-                        choices=['aom', 'svt_av1', 'rav1e', 'vpx'])
+                        choices=['aom', 'svt_av1', 'rav1e', 'vpx','x265'])
     parser.add_argument('--workers', '-w', type=int, default=0, help='Number of workers')
     parser.add_argument('-cfg', '--config', type=Path, help='Parameters file. Save/Read: '
                                                             'Video, Audio, Encoder, FFmpeg parameteres')
@@ -48,8 +107,8 @@ def arg_parsing():
     # Boost
     parser.add_argument('--boost', help='Experimental feature, decrease CQ of clip based on brightness.'
                                         'Darker = lower CQ', action='store_true')
-    parser.add_argument('--boost_range', '-bl', default=15, type=int, help='Range/strength of CQ change')
-    parser.add_argument('--boost_limit', '-br', default=10, type=int, help='CQ limit for boosting')
+    parser.add_argument('--boost_range', '-br', default=15, type=int, help='Range/strength of CQ change')
+    parser.add_argument('--boost_limit', '-bl', default=10, type=int, help='CQ limit for boosting')
 
     # Vmaf
     parser.add_argument('--vmaf', help='Calculating vmaf after encode', action='store_true')
@@ -61,6 +120,6 @@ def arg_parsing():
     parser.add_argument('--min_cq', type=int, default=25, help='Min cq for target vmaf')
     parser.add_argument('--max_cq', type=int, default=50, help='Max cq for target vmaf')
     parser.add_argument('--vmaf_plots', help='Make plots of probes in temp folder', action='store_true')
+    parser.add_argument('--n_threads', type=int, default=None, help='Threads for vmaf calculation')
 
-    # Store all vars in dictionary
-    return vars(parser.parse_args())
+    return Args(vars(parser.parse_args()))
