@@ -1,14 +1,14 @@
 #!/bin/env python
 
+
 import subprocess
-from subprocess import PIPE, STDOUT
-import shutil
 from pathlib import Path
+from subprocess import PIPE, STDOUT
 
 from .logger import log
 
 
-def concatenate_video(temp, output, keep=False):
+def concatenate_video(temp, output, encoder):
     """With FFMPEG concatenate encoded segments into final file."""
 
     log('Concatenating\n')
@@ -22,21 +22,29 @@ def concatenate_video(temp, output, keep=False):
     # Add the audio file if one was extracted from the input
     audio_file = temp / "audio.mkv"
     if audio_file.exists():
-        audio = f'-i {audio_file} -c:a copy'
+        audio = f'-i {audio_file} -c:a copy -map 1'
     else:
         audio = ''
 
-    cmd = f' ffmpeg -y -hide_banner -loglevel error -f concat -safe 0 -i {temp / "concat"} ' \
-          f'{audio} -c copy -y "{output}"'
-    concat = subprocess.run(cmd, shell=True, stdout=PIPE, stderr=STDOUT).stdout
+    if encoder == 'x265':
+
+        cmd = f' ffmpeg -y -fflags +genpts  -hide_banner -loglevel error -f concat -safe 0 -i {temp / "concat"} ' \
+            f'{audio} -c copy -movflags frag_keyframe+empty_moov -map 0  -f mp4 - | ffmpeg -y -hide_banner -loglevel error -i - -c copy {output} '
+        concat = subprocess.run(cmd, shell=True, stdout=PIPE, stderr=STDOUT).stdout
+
+    else:
+        cmd = f' ffmpeg -y -hide_banner -loglevel error -f concat -safe 0 -i {temp / "concat"} ' \
+            f'{audio} -c copy -map 0  -y "{output}"'
+
+        concat = subprocess.run(cmd, shell=True, stdout=PIPE, stderr=STDOUT).stdout
+
+
     if len(concat) > 0:
         log(concat.decode())
         print(concat.decode())
         raise Exception
 
-    # Delete temp folders
-    if not keep:
-        shutil.rmtree(temp)
+
 
 
 def extract_audio(input_vid: Path, temp, audio_params):
