@@ -2,11 +2,12 @@
 
 import os
 import shutil
+from distutils.spawn import find_executable
 from pathlib import Path
+
 from psutil import virtual_memory
 
 from .utils import terminate
-from distutils.spawn import find_executable
 
 
 def determine_resources(encoder, workers):
@@ -22,7 +23,7 @@ def determine_resources(encoder, workers):
     if encoder in ('aom', 'rav1e', 'vpx'):
         workers =  round(min(cpu / 2, ram / 1.5))
 
-    elif encoder == 'svt_av1':
+    elif encoder in ('svt_av1', 'x265'):
         workers =  round(min(cpu, ram)) // 5
 
     # fix if workers round up to 0
@@ -33,7 +34,7 @@ def determine_resources(encoder, workers):
 
 
 def check_executables(encoder):
-    encoders = {'svt_av1': 'SvtAv1EncApp', 'rav1e': 'rav1e', 'aom': 'aomenc', 'vpx': 'vpxenc'}
+    encoders = {'svt_av1': 'SvtAv1EncApp', 'rav1e': 'rav1e', 'aom': 'aomenc', 'vpx': 'vpxenc','x265': 'x265'}
     if not find_executable('ffmpeg'):
         print('No ffmpeg')
         terminate()
@@ -46,7 +47,7 @@ def check_executables(encoder):
             print(f'Encoder {enc} not found')
             terminate()
     else:
-        print(f'Not valid encoder {encoder}\nValid encoders: "aom rav1e", "svt_av1", "vpx" ')
+        print(f'Not valid encoder {encoder}\nValid encoders: "aom rav1e", "svt_av1", "vpx", "x265" ')
         terminate()
 
 
@@ -61,8 +62,9 @@ def setup(temp: Path, resume):
     (temp / 'encode').mkdir(exist_ok=True)
 
 
-def outputs_filenames(inp: Path, out:Path):
+def outputs_filenames(inp: Path, out:Path, encoder):
+    suffix = '.mkv'
     if out:
-        return out.with_suffix('.mkv')
+        return out.with_suffix(suffix)
     else:
-        return Path(f'{inp.stem}_av1.mkv')
+        return Path(f'{inp.stem}_av1{suffix}')
