@@ -44,11 +44,7 @@ def process_inputs(inputs):
         print(f'File(s) do not exist: {", ".join([str(inputs[i]) for i in np.where(not valid)[0]])}')
         terminate()
 
-    if len(inputs) > 1:
-        return inputs, None
-    else:
-        return None, inputs[0]
-
+    return inputs
 
 def get_keyframes(file: Path):
     """
@@ -91,13 +87,19 @@ def get_cq(command):
     return int(matches[-1])
 
 
-def man_cq(command: str, cq: int):
+def man_q(command: str, q: int):
     """Return command with new cq value"""
-    mt = '--cq-level='
-    cmd = command[:command.find(mt) + 11] + str(cq) + command[command.find(mt) + 13:]
+    if 'aomenc' in command:
+        mt = '--cq-level='
+        cmd = command[:command.find(mt) + 11] + str(q) + ' ' + command[command.find(mt) + 13:]
+    elif 'x265' in command:
+        mt = '--crf'
+        cmd = command[:command.find(mt) + 6] + str(q) + ' ' +  command[command.find(mt) + 9:]
+
     return cmd
 
 
+
 def frame_probe_fast(source: Path):
     video = cv2.VideoCapture(source.as_posix())
     total = int(video.get(cv2.CAP_PROP_FRAME_COUNT))
@@ -128,7 +130,7 @@ def frame_check(source: Path, encoded: Path, temp, check):
                 json.dump(d, f)
         else:
             s1, s2 = [frame_probe(i) for i in (source, encoded)]
-            if s1 == s2:
+            if s1 <= s2:
                 doneFileLock.acquire()
                 with status_file.open() as f:
                     d = json.load(f)
